==> hs-sendfile-0.7.6_1.tbz: lib/ghc-7.4.1/cabal/sendfile-0.7.6/register.sh <==
#!/bin/sh
echo 'name: sendfile
version: 0.7.6
id: sendfile-0.7.6-e77d10acc0d9d5615d0d5ec9599655d9

license: BSD3
copyright:
maintainer: Jeremy Shaw <jeremy@n-heptane.com>
stability: provisional
homepage: http://patch-tag.com/r/mae/sendfile
package-url:
synopsis: A portable sendfile library
description: A library which exposes zero-copy sendfile functionality in a portable way. If a platform does not support sendfile, a fallback implementation in haskell is provided.
             .
             Currently supported platforms: Windows 2000+ (Native), Linux 2.6+ (Native), FreeBSD (Native), OS-X 10.5+ (Native), Everything else (Portable Haskell code).
category: Network
author: Matthew Elder <matt@mattelder.org>
exposed: True
exposed-modules: Network.Socket.SendFile
                 Network.Socket.SendFile.Iter Network.Socket.SendFile.Handle
                 Network.Socket.SendFile.Portable
hidden-modules: Network.Socket.SendFile.FreeBSD
                Network.Socket.SendFile.Internal Network.Socket.SendFile.Util
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/sendfile-0.7.6
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/sendfile-0.7.6
              /usr/local/lib
hs-libraries: HSsendfile-0.7.6
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.5.0.0-1a022b3476300ed3e5bfdd46dd7221d0
         bytestring-0.9.2.1-e2bcd9910229fcb291a3a8dd6f79f7fe
         network-2.3.0.13-61384c729042da4a510c1f2707b5d629
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/sendfile-0.7.6/html/sendfile.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/sendfile-0.7.6/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-sendfile-0.7.9.tbz: lib/ghc-7.4.2/cabal/sendfile-0.7.9/register.sh <==
#!/bin/sh
echo 'name: sendfile
version: 0.7.9
id: sendfile-0.7.9-4612c25822e4b050c320793bb07e3e4d

license: BSD3
copyright:
maintainer: Jeremy Shaw <jeremy@n-heptane.com>
stability: provisional
homepage: http://hub.darcs.net/stepcut/sendfile
package-url:
synopsis: A portable sendfile library
description: A library which exposes zero-copy sendfile functionality in a portable way. If a platform does not support sendfile, a fallback implementation in haskell is provided.
             .
             Currently supported platforms: Windows 2000+ (Native), Linux 2.6+ (Native), FreeBSD (Native), OS-X 10.5+ (Native), Everything else (Portable Haskell code).
category: Network
author: Matthew Elder <matt@mattelder.org>
exposed: True
exposed-modules: Network.Socket.SendFile
                 Network.Socket.SendFile.Iter Network.Socket.SendFile.Handle
                 Network.Socket.SendFile.Portable
hidden-modules: Network.Socket.SendFile.FreeBSD
                Network.Socket.SendFile.Internal Network.Socket.SendFile.Util
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/sendfile-0.7.9
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/sendfile-0.7.9
              /usr/local/lib
hs-libraries: HSsendfile-0.7.9
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.5.1.0-f58939ca866a8377999e7a71aa62d1d0
         bytestring-0.9.2.1-4cc8a513193316dfe32ba33f47609c9d
         network-2.3.1.0-6b6d66ee2df4c4f37033da9ed9847211
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/sendfile-0.7.9/html/sendfile.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/sendfile-0.7.9/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
